import logging

import aiohttp

logger = logging.getLogger(__name__)


class NtfyNotifier:
    def __init__(self, ntfy_url: str = "https://ntfy.homelab.net") -> None:
        self._ntfy_url = ntfy_url

    async def send_notification(self, camera: str, status: bool) -> None:
        async with aiohttp.ClientSession(raise_for_status=True) as aiohttp_session:
            logger.debug(f"Sending notification for {camera=}...")
            message = f"{camera} is back online" if status else f"{camera} is offline"
            await aiohttp_session.post(self._ntfy_url, ssl=False, json={
                "topic": "frigate_camera_uptime",
                "title": "Frigate",
                "message": message,
                "priority": 3,
                "click": f"https://frigate.homelab.net/cameras/{camera}",
                "icon": "https://cdn.jsdelivr.net/gh/walkxcode/dashboard-icons/png/frigate.png",
            })
            logger.debug(f"Sent notification for {camera=}")
