import logging
import os

import yaml

logger = logging.getLogger(__name__)


class FrigateConfigFile:
    def __init__(self, filepath: str = os.environ["FRIGATE_CONFIG_FILE"]) -> None:
        self._filepath = filepath
        self._config = {}

    async def reload(self) -> None:
        logger.debug("Loading Frigate configuration file")
        try:
            with open(self._filepath, "r") as frigate_config_yaml:
                self._config = yaml.safe_load(frigate_config_yaml)
        except Exception as e:
            if self._config:
                logger.error("Failed to load Frigate config file, falling back to previous value", exc_info=e)
            else:
                raise
        logger.debug("Loaded Frigate configuration file")

    @property
    def active_cameras(self) -> list[str]:
        if not self._config:
            raise ValueError("Configuration file not yet loaded from Frigate")

        return [
            camera
            for camera in self._config["cameras"]
            if self._config["cameras"][camera].get("enabled", True)
        ]

    @property
    def detection_enabled_cameras(self) -> list[str]:
        if not self._config:
            raise ValueError("Configuration file not yet loaded from Frigate")

        return [
            camera
            for camera in self._config["cameras"]
            if self._config["cameras"][camera].get("detect", {}).get("enabled", True)
        ]
